var searchData=
[
  ['data_0',['Data',['../structflecs_1_1units_1_1Data.html',1,'flecs::units::Data'],['../group__cpp__addons__units__data.html',1,'Data'],['../group__c__addons__units__data.html',1,'Data']]],
  ['data_1',['data',['../md_docs_2DesignWithFlecs.html#complex-component-data',1,'Complex component data'],['../structflecs_1_1units_1_1data.html',1,'flecs::units::data'],['../structecs__bulk__desc__t.html#a204153d9fa00a4bef093f20b3978d3d9',1,'ecs_bulk_desc_t::data']]],
  ['data_20from_20my_20application_2',['Does the explorer collect data from my application?',['../md_docs_2FAQ.html#does-the-explorer-collect-data-from-my-application',1,'']]],
  ['data_20rate_3',['Data Rate',['../group__cpp__addons__units__datarate.html',1,'Data Rate'],['../group__c__addons__units__datarate.html',1,'Data Rate']]],
  ['data_5ffields_4',['data_fields',['../structecs__query__t.html#a0742ff1af4d11553f79f17edabdbc513',1,'ecs_query_t']]],
  ['datarate_5',['DataRate',['../structflecs_1_1units_1_1DataRate.html',1,'flecs::units']]],
  ['datarate_6',['datarate',['../structflecs_1_1units_1_1datarate.html',1,'flecs::units']]],
  ['date_7',['Date',['../structflecs_1_1units_1_1time_1_1Date.html',1,'flecs::units::time']]],
  ['days_8',['Days',['../structflecs_1_1units_1_1duration_1_1Days.html',1,'flecs::units::duration']]],
  ['dbg_9',['dbg',['../group__cpp__log.html#gab5bb3c0713f111e88a6ae43c3b9abe06',1,'flecs::log']]],
  ['debug_10',['debug',['../structecs__build__info__t.html#af2735a6a8d0994173a3bbcf9b4e1ee9e',1,'ecs_build_info_t']]],
  ['deca_11',['Deca',['../structflecs_1_1units_1_1Deca.html',1,'flecs::units']]],
  ['deci_12',['Deci',['../structflecs_1_1units_1_1Deci.html',1,'flecs::units']]],
  ['decibel_13',['DeciBel',['../structflecs_1_1units_1_1DeciBel.html',1,'flecs::units']]],
  ['decl_2ehpp_14',['decl.hpp',['../alerts_2decl_8hpp.html',1,'(Global Namespace)'],['../app_2decl_8hpp.html',1,'(Global Namespace)'],['../doc_2decl_8hpp.html',1,'(Global Namespace)'],['../event_2decl_8hpp.html',1,'(Global Namespace)'],['../id_2decl_8hpp.html',1,'(Global Namespace)'],['../json_2decl_8hpp.html',1,'(Global Namespace)'],['../meta_2decl_8hpp.html',1,'(Global Namespace)'],['../metrics_2decl_8hpp.html',1,'(Global Namespace)'],['../observer_2decl_8hpp.html',1,'(Global Namespace)'],['../pipeline_2decl_8hpp.html',1,'(Global Namespace)'],['../query_2decl_8hpp.html',1,'(Global Namespace)'],['../rest_2decl_8hpp.html',1,'(Global Namespace)'],['../script_2decl_8hpp.html',1,'(Global Namespace)'],['../stats_2decl_8hpp.html',1,'(Global Namespace)'],['../system_2decl_8hpp.html',1,'(Global Namespace)'],['../term_2decl_8hpp.html',1,'(Global Namespace)'],['../timer_2decl_8hpp.html',1,'(Global Namespace)'],['../units_2decl_8hpp.html',1,'(Global Namespace)']]],
  ['default_15',['Default',['../md_docs_2Queries.html#default',1,'']]],
  ['default_20components_16',['Default components',['../md_docs_2FlecsScript.html#default-components',1,'']]],
  ['defer_17',['defer',['../structflecs_1_1world.html#a45451da00e10f8aa89e6edeb34091b12',1,'flecs::world']]],
  ['defer_5fbegin_18',['defer_begin',['../structflecs_1_1world.html#a534f0ae1bd1a2f73807c6e971936590f',1,'flecs::world']]],
  ['defer_5fend_19',['defer_end',['../structflecs_1_1world.html#a8472e8ad9814d31ee0cef6382c21dcb2',1,'flecs::world']]],
  ['defer_5fresume_20',['defer_resume',['../structflecs_1_1world.html#a6c38616a9bec8932f6c7117d6846e45e',1,'flecs::world']]],
  ['defer_5fsuspend_21',['defer_suspend',['../structflecs_1_1world.html#a569b827fcddf68df112397fe6225327a',1,'flecs::world']]],
  ['deferred_20operations_22',['Deferred operations',['../md_docs_2Manual.html#deferred-operations',1,'']]],
  ['defines_23',['API defines',['../group__options.html',1,'']]],
  ['defining_20modules_24',['Defining Modules',['../md_docs_2DesignWithFlecs.html#defining-modules',1,'']]],
  ['definitions_25',['Definitions',['../md_docs_2Queries.html#definitions',1,'Definitions'],['../md_docs_2Relationships.html#definitions-1',1,'Definitions']]],
  ['degrees_26',['Degrees',['../structflecs_1_1units_1_1angle_1_1Degrees.html',1,'flecs::units::angle']]],
  ['delegate_27',['delegate',['../structflecs_1_1___1_1delegate.html',1,'flecs::_']]],
  ['delegate_2ehpp_28',['delegate.hpp',['../delegate_8hpp.html',1,'']]],
  ['delete_29',['Delete',['../md_docs_2ComponentTraits.html#ondelete-delete',1,'(OnDelete, Delete)'],['../md_docs_2ComponentTraits.html#ondeletetarget-delete',1,'(OnDeleteTarget, Delete)']]],
  ['delete_20component_30',['DELETE component',['../md_docs_2FlecsRemoteApi.html#delete-component',1,'']]],
  ['delete_20entity_31',['DELETE entity',['../md_docs_2FlecsRemoteApi.html#delete-entity',1,'']]],
  ['delete_5fcount_32',['delete_count',['../structecs__world__info__t.html#abda93bc5d7bb20903380851b79ac4ea2',1,'ecs_world_info_t::delete_count'],['../structecs__world__stats__t.html#a1bdd27808a598f06f9d505e7c124a32f',1,'ecs_world_stats_t::delete_count']]],
  ['delete_5fwith_33',['delete_with',['../structflecs_1_1world.html#a16d83b55db96e295059ce7b0f3b0366b',1,'flecs::world::delete_with(id_t the_id) const'],['../structflecs_1_1world.html#adf6cc2b38b44b9ae223f5389dc8e79ce',1,'flecs::world::delete_with(entity_t first, entity_t second) const'],['../structflecs_1_1world.html#a049583b02a7e8cda7e7d5b71c4e5a5b1',1,'flecs::world::delete_with() const'],['../structflecs_1_1world.html#ae1d0dbd4c31f16180831d4601e76f6f5',1,'flecs::world::delete_with() const'],['../structflecs_1_1world.html#a10dc9ac710d729b12d15531f9c84b087',1,'flecs::world::delete_with(entity_t second) const']]],
  ['deleting_34',['Creating &amp; Deleting',['../group__creating__entities.html',1,'']]],
  ['deletion_35',['Deletion',['../group__world__creation__deletion.html',1,'Creation &amp; Deletion'],['../group__flecs__c__creation__deletion.html',1,'Creation &amp; Deletion'],['../md_docs_2EntitiesComponents.html#deletion',1,'Deletion']]],
  ['delta_5fsystem_5ftime_36',['delta_system_time',['../structecs__iter__t.html#a92e7402ad71e8bd79d4950cac78d0bcc',1,'ecs_iter_t']]],
  ['delta_5ftime_37',['delta_time',['../structecs__iter__t.html#aad39d90d9e5b277e767121e44323c1f3',1,'ecs_iter_t::delta_time'],['../structecs__world__info__t.html#a064a745a142d7865c93895fafaa57891',1,'ecs_world_info_t::delta_time'],['../structecs__app__desc__t.html#a5a83b7e5039a2e2451b13b508d72df1e',1,'ecs_app_desc_t::delta_time'],['../structecs__world__stats__t.html#af952e64299d3b73d1183456349cf83c3',1,'ecs_world_stats_t::delta_time'],['../structflecs_1_1world.html#a2bd7f3756702f73c31ed742c9fed21cf',1,'flecs::world::delta_time()'],['../md_docs_2Systems.html#using-delta_time',1,'Using delta_time']]],
  ['delta_5ftime_5fraw_38',['delta_time_raw',['../structecs__world__info__t.html#a423da320e10ad87b102a25bd74368ed0',1,'ecs_world_info_t']]],
  ['demo_20s_39',['Flecs Demo&apos;s',['../index.html#flecs-demos',1,'']]],
  ['demos_40',['Demos',['../md_docs_2Docs.html#demos',1,'']]],
  ['dense_41',['dense',['../structecs__record__t.html#a89933d2aedbdcb2b82b579c8f356c348',1,'ecs_record_t']]],
  ['dependencies_20and_20ordering_42',['Module Dependencies and Ordering',['../md_docs_2DesignWithFlecs.html#module-dependencies-and-ordering',1,'']]],
  ['dependent_20variables_43',['Dependent variables',['../md_docs_2FlecsQueryLanguage.html#dependent-variables',1,'']]],
  ['depends_5fon_44',['depends_on',['../structflecs_1_1entity__builder.html#ace125c47b515609467906f96163c0861',1,'flecs::entity_builder::depends_on(entity_t second) const'],['../structflecs_1_1entity__builder.html#a79433c1ec01dd26b6e70ddf76b772585',1,'flecs::entity_builder::depends_on(E second) const'],['../structflecs_1_1entity__builder.html#ad1194ea6452b0b33c03f47e114a409d0',1,'flecs::entity_builder::depends_on() const']]],
  ['deprecated_2eh_45',['deprecated.h',['../deprecated_8h.html',1,'']]],
  ['depth_46',['depth',['../structecs__meta__cursor__t.html#aa59bd4e2a1f56a610e961d7a0a125ba2',1,'ecs_meta_cursor_t::depth'],['../structflecs_1_1entity__view.html#a0d7ed298781771ceda93212b0bfa8905',1,'flecs::entity_view::depth(flecs::entity_t rel) const'],['../structflecs_1_1entity__view.html#a3ee3934868dc56595448dad7413ea926',1,'flecs::entity_view::depth() const'],['../structflecs_1_1table.html#aac9c20bbb66b6af3cc68d8e34c76e256',1,'flecs::table::depth(flecs::entity_t rel)'],['../structflecs_1_1table.html#a8372484d6d5ec13562dd8e254e2d8d77',1,'flecs::table::depth()']]],
  ['description_47',['Description',['../group__cpp__addons__doc.html#gad0795b4455fcad1eb215090c2b0dbe7e',1,'flecs::doc']]],
  ['descriptor_20types_48',['Query descriptor types.',['../group__query__types.html',1,'']]],
  ['design_49',['API design',['../md_docs_2Manual.html#api-design',1,'']]],
  ['design_20goals_50',['Design Goals',['../md_docs_2Manual.html#design-goals',1,'']]],
  ['designing_20with_20flecs_51',['Designing with Flecs',['../md_docs_2DesignWithFlecs.html',1,'']]],
  ['destruct_52',['destruct',['../structflecs_1_1entity.html#a05c1af95015764fc68aa790d274f4462',1,'flecs::entity::destruct()'],['../structflecs_1_1query__base.html#ae788911f0a5cb6afb580192774d7a3b0',1,'flecs::query_base::destruct()']]],
  ['detect_20which_20entities_20have_20changed_53',['How do I detect which entities have changed?',['../md_docs_2FAQ.html#how-do-i-detect-which-entities-have-changed',1,'']]],
  ['detection_54',['Change Detection',['../md_docs_2Queries.html#change-detection',1,'']]],
  ['difference_20between_20add_20set_20why_20do_20both_20exist_55',['What is the difference between add &amp; set? Why do both exist?',['../md_docs_2FAQ.html#what-is-the-difference-between-add--set-why-do-both-exist',1,'']]],
  ['dim_56',['dim',['../structflecs_1_1world.html#a75f65adc46f2bf3023383add505c4ff7',1,'flecs::world']]],
  ['disable_57',['disable',['../structflecs_1_1entity__builder.html#a04cf84a7131b162ba2b84ecaa552fb84',1,'flecs::entity_builder::disable() const'],['../structflecs_1_1entity__builder.html#a5e9b68ad145c42dbf820807010b42f15',1,'flecs::entity_builder::disable(flecs::id_t id) const'],['../structflecs_1_1entity__builder.html#a8def0956e65d1875a55e074d8c708dca',1,'flecs::entity_builder::disable() const'],['../structflecs_1_1entity__builder.html#a2ab0a844d5f4a0b1865578a2bf19af57',1,'flecs::entity_builder::disable(flecs::id_t first, flecs::id_t second) const'],['../structflecs_1_1entity__builder.html#aad4e63fb80096e9cb50f84f54c12ed1e',1,'flecs::entity_builder::disable(flecs::id_t second) const'],['../structflecs_1_1entity__builder.html#ae589845d6f26fa740fd7eb8d70dfe7bf',1,'flecs::entity_builder::disable() const']]],
  ['disabling_58',['Disabling',['../md_docs_2EntitiesComponents.html#disabling',1,'Disabling'],['../md_docs_2EntitiesComponents.html#disabling-1',1,'Disabling'],['../group__enabling__disabling.html',1,'Enabling &amp; Disabling'],['../group__flecs__c__enable__disable.html',1,'Enabling &amp; Disabling']]],
  ['disabling_59',['disabling',['../md_docs_2MigrationGuide.html#component-disabling',1,'Component disabling'],['../md_docs_2ObserversManual.html#observer-disabling',1,'Observer disabling']]],
  ['disabling_20systems_60',['Disabling systems',['../md_docs_2Systems.html#disabling-systems',1,'']]],
  ['discard_5fcount_61',['discard_count',['../structecs__world__info__t.html#a8903bd78dec7d3e3587449550ce78757',1,'ecs_world_info_t']]],
  ['dlclose_5f_62',['dlclose_',['../structecs__os__api__t.html#afcd6f42ffe5c9d801967d44ac44788a0',1,'ecs_os_api_t']]],
  ['dlopen_5f_63',['dlopen_',['../structecs__os__api__t.html#a534fc92901c5584eab02f095f8383d76',1,'ecs_os_api_t']]],
  ['dlproc_5f_64',['dlproc_',['../structecs__os__api__t.html#af129e053c5a2c5f79e0365bd98423e57',1,'ecs_os_api_t']]],
  ['do_20both_20exist_65',['What is the difference between add &amp; set? Why do both exist?',['../md_docs_2FAQ.html#what-is-the-difference-between-add--set-why-do-both-exist',1,'']]],
  ['do_20i_20detect_20which_20entities_20have_20changed_66',['How do I detect which entities have changed?',['../md_docs_2FAQ.html#how-do-i-detect-which-entities-have-changed',1,'']]],
  ['doc_67',['Doc',['../group__cpp__addons__doc.html',1,'Doc'],['../group__c__addons__doc.html',1,'Doc']]],
  ['doc_2eh_68',['doc.h',['../doc_8h.html',1,'']]],
  ['doc_5fbrief_69',['doc_brief',['../group__cpp__addons__doc.html#gabf672e81afeddec4a4e2c0f8250ff021',1,'flecs::entity_view::doc_brief() const'],['../structflecs_1_1entity__view.html#gabf672e81afeddec4a4e2c0f8250ff021',1,'flecs::entity_view::doc_brief() const'],['../structflecs_1_1entity__view.html#gabf672e81afeddec4a4e2c0f8250ff021',1,'flecs::doc_brief()']]],
  ['doc_5fcolor_70',['doc_color',['../group__cpp__addons__doc.html#gac9ee07df2042efd85259a7cf2c4e55f6',1,'flecs::entity_view::doc_color() const'],['../structflecs_1_1entity__view.html#gac9ee07df2042efd85259a7cf2c4e55f6',1,'flecs::entity_view::doc_color() const'],['../structflecs_1_1entity__view.html#gac9ee07df2042efd85259a7cf2c4e55f6',1,'flecs::doc_color()']]],
  ['doc_5fdetail_71',['doc_detail',['../group__cpp__addons__doc.html#gaad57d5f8523631450f0e3ea083fb0d35',1,'flecs::entity_view::doc_detail() const'],['../structflecs_1_1entity__view.html#gaad57d5f8523631450f0e3ea083fb0d35',1,'flecs::entity_view::doc_detail() const'],['../structflecs_1_1entity__view.html#gaad57d5f8523631450f0e3ea083fb0d35',1,'flecs::doc_detail()']]],
  ['doc_5flink_72',['doc_link',['../group__cpp__addons__doc.html#gaa537a0f49dbd7c563900f2480f85d6a0',1,'flecs::entity_view::doc_link() const'],['../structflecs_1_1entity__view.html#gaa537a0f49dbd7c563900f2480f85d6a0',1,'flecs::entity_view::doc_link() const'],['../structflecs_1_1entity__view.html#gaa537a0f49dbd7c563900f2480f85d6a0',1,'flecs::doc_link()']]],
  ['doc_5fname_73',['doc_name',['../structecs__alert__desc__t.html#aa9bbb8c2495dc6b281378d4403d95ef7',1,'ecs_alert_desc_t::doc_name'],['../group__cpp__addons__doc.html#ga53dd532bce312cc69414e44c4cb9f938',1,'flecs::entity_view::doc_name()'],['../structflecs_1_1alert__builder__i.html#a3e72987051e58d7bc94f98b7ce95c5ce',1,'flecs::alert_builder_i::doc_name()'],['../structflecs_1_1entity__view.html#ga53dd532bce312cc69414e44c4cb9f938',1,'flecs::entity_view::doc_name()'],['../structflecs_1_1entity__view.html#ga53dd532bce312cc69414e44c4cb9f938',1,'flecs::doc_name()']]],
  ['documentation_74',['Documentation',['../md_docs_2Docs.html',1,'']]],
  ['does_20a_20locked_5fstorage_20error_20mean_75',['What does a LOCKED_STORAGE error mean?',['../md_docs_2FAQ.html#what-does-a-locked_storage-error-mean',1,'']]],
  ['does_20flecs_20compare_20with_20entt_76',['How does Flecs compare with EnTT?',['../md_docs_2FAQ.html#how-does-flecs-compare-with-entt',1,'']]],
  ['does_20the_20explorer_20collect_20data_20from_20my_20application_77',['Does the explorer collect data from my application?',['../md_docs_2FAQ.html#does-the-explorer-collect-data-from-my-application',1,'']]],
  ['does_20the_20explorer_20not_20work_78',['Why does the explorer not work?',['../md_docs_2FAQ.html#why-does-the-explorer-not-work',1,'']]],
  ['does_20the_20lookup_20function_20not_20find_20my_20entity_79',['Why does the lookup function not find my entity?',['../md_docs_2FAQ.html#why-does-the-lookup-function-not-find-my-entity',1,'']]],
  ['dont_5fserialize_5fresults_80',['dont_serialize_results',['../structecs__iter__to__json__desc__t.html#a531e1e0a6d9c5486c790c925350006da',1,'ecs_iter_to_json_desc_t']]],
  ['dontinherit_81',['DontInherit',['../md_docs_2ComponentTraits.html#dontinherit',1,'']]],
  ['downgrading_82',['Event Downgrading',['../md_docs_2ObserversManual.html#event-downgrading',1,'']]],
  ['drawing_20a_20fence_83',['Drawing a Fence',['../flecsscripttutorial.html#drawing-a-fence',1,'']]],
  ['drawing_20shapes_84',['Drawing Shapes',['../flecsscripttutorial.html#drawing-shapes',1,'']]],
  ['dsl_85',['Query DSL',['../md_docs_2MigrationGuide.html#query-dsl',1,'']]],
  ['dtor_86',['dtor',['../structecs__type__hooks__t.html#afc86220bdd889357b3185ce7a97a282b',1,'ecs_type_hooks_t']]],
  ['duration_87',['Duration',['../structflecs_1_1units_1_1Duration.html',1,'flecs::units::Duration'],['../group__cpp__addons__units__duration.html',1,'Duration'],['../group__c__addons__units__duration.html',1,'Duration']]],
  ['duration_88',['duration',['../structflecs_1_1units_1_1duration.html',1,'flecs::units']]],
  ['during_20world_20teardown_89',['Cleanup order during world teardown',['../md_docs_2ComponentTraits.html#cleanup-order-during-world-teardown',1,'']]],
  ['dynamic_20linking_90',['Dynamic linking',['../md_docs_2Quickstart.html#dynamic-linking',1,'']]]
];
